#######################################################################
#
# ncm-rm script for the EDG Replica Manager
#
# Novak Judit <judit.novak@cern.ch>
# Version 0.1.12 : 17/12/04 16:24
#
# Component to manage top-level EDG replica-manager configuration.
#
#######################################################################

package NCM::Component::rm;
use strict;
use NCM::Component;
use vars qw(@ISA $EC);
@ISA = qw(NCM::Component);
$EC=LC::Exception::Context->new->will_store_all;
use NCM::Check;

use EDG::WP4::CCM::Element;
use LC::Process;


##########################################################################
sub Configure($$@) {
##########################################################################

	my ($self, $config) = @_;
  	my $compName = 'edg-replica-manager';
	my $edgconfigpath = "/system/edg/config";

	# HACK: Unset EDG_LOCATION as a workaround bug #4418.
	delete $ENV{EDG_LOCATION};

   	# Parse definition file
	my $loce = $config->getElement( "$edgconfigpath/EDG_LOCATION" );
	my $edglocation=$loce->getValue();

	# Configuration of replica manager 
	my $conffile = "$edglocation/etc/$compName/$compName.conf.quattor";
	
	my %rmconf;
	$rmconf{'edglocation'}=$edglocation;
	my $rme = $config->getElement('/software/components/rm/');
	while ( $rme->hasNextElement() ) {
		my $element = $rme->getNextElement();
		if ( $element->isProperty() ) {
			my $name = $element->getName();
			my $value = $element->getValue();
			$rmconf{$name} = $value;
		}
	}
#	my @vars = ( 'localdomain', 'defaultse', 'defaultce', 'infoprovider',
#				 'stubfile', 'mdshost', 'mdsport', 'failifnoros');
#	foreach (@vars) {
#		unless (exists $rmconf{"$_"}) {
#			$self->error("Configuration variable $_ is missing");
#			return
#		}
#	}
	
	my $contents = "";
	my $datafile = "/usr/lib/ncm/config/rm/template.cin";
	open( DATA, "< $datafile"  );
	while (<DATA>) {
		my ($var) = /<%(.*)%>/;
		if ( defined $var) {
		  if (exists $rmconf{$var} ) {
		    s/<%$var%>/$rmconf{$var}/;
		  } else {
		    s/<%$var%>//;
		  }
		}
		$contents .= $_;
	}
	close( DATA );

	if ( ! -e $conffile ) {
  		open ( CONF,">$conffile " );
		print CONF $contents;
		close ( CONF );
		$self->log("$conffile created");
	} else {
		my $result = LC::Check::file( $conffile,
				backup => ".old",
				contents => $contents
			);
		$self->log("$conffile updated") if $result;
	}


# call configure
my $configArgs = "$edglocation/sbin/$compName-configure ".
		 $conffile;

my ($stdout,$stderr);

my $execute_status = LC::Process::execute([ $configArgs ],
                                              timeout => 1800,
                                              stdout => \$stdout,
                                              stderr => \$stderr
                                              );
if ($?) {
	$self->error("$configArgs failed: $?");
}

if ($stdout) {
      $self->info("$configArgs output produced:");
      $self->report($stdout);
}

if ($stderr) {
      $self->warn("$configArgs STDERR output produced:");
      $self->report($stderr);
}



}

1 # Required for PERL modulues
